@@ -5,8 +5,8 @@
 	@module
 */
 
-#ifndef __WRAPS_ATTRIBUTE_H__
-#define __WRAPS_ATTRIBUTE_H__
+#ifndef WRAPS_ATTRIBUTE_H_
+#define WRAPS_ATTRIBUTE_H_
 
 #include <MyGUI.h>
 #include "Attribute.h"
@@ -21,7 +21,7 @@ namespace attribute
 		template <typename Type>
 		static Type* convert(BaseValueType* _value)
 		{
-			return _value == 0 ? 0 : _value->castType<Type>(false);
+			return _value == nullptr ? nullptr : _value->castType<Type>(false);
 		}
 	};
 
@@ -31,12 +31,6 @@ namespace attribute
 	ATTRIBUTE_FIELD(AttributeFieldWidgetName, _class, _field, _value)
 
 
-	DECLARE_ATTRIBUTE_CLASS(AttributeSize, MyGUI::IntSize);
-
-#define ATTRIBUTE_CLASS_SIZE(_class, _value) \
-	ATTRIBUTE_CLASS(AttributeSize, _class, _value)
-
-
 	DECLARE_ATTRIBUTE_CLASS(AttributeLayout, std::string);
 
 #define ATTRIBUTE_CLASS_LAYOUT(_class, _value) \
@@ -44,4 +38,4 @@ namespace attribute
 
 }
 
-#endif // __WRAPS_ATTRIBUTE_H__
+#endif // WRAPS_ATTRIBUTE_H_
