@@ -8,6 +8,7 @@
 #define MYGUI_FONT_DATA_H_
 
 #include "MyGUI_Prerequest.h"
+#include "MyGUI_Types.h"
 
 namespace MyGUI
 {
@@ -15,7 +16,7 @@ namespace MyGUI
 	namespace FontCodeType
 	{
 
-		enum Enum
+		enum Enum : MyGUI::Char
 		{
 			Tab = 0x0009,
 			LF = 0x000A,
@@ -64,7 +65,7 @@ namespace MyGUI
 		FloatRect uvRect;
 	};
 
-	typedef std::vector<GlyphInfo> VectorGlyphInfo;
+	using VectorGlyphInfo = std::vector<GlyphInfo>;
 
 } // namespace MyGUI
 
