@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_I_LOG_FILTER_H__
-#define __MYGUI_I_LOG_FILTER_H__
+#ifndef MYGUI_I_LOG_FILTER_H_
+#define MYGUI_I_LOG_FILTER_H_
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_LogLevel.h"
@@ -16,7 +16,7 @@ namespace MyGUI
 	class MYGUI_EXPORT ILogFilter
 	{
 	public:
-		virtual ~ILogFilter() { }
+		virtual ~ILogFilter() = default;
 
 		/** Check if specific log message should be logged.\n
 			For example some log listeners use only messages with high log level.
@@ -29,4 +29,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_I_LOG_FILTER_H__
+#endif // MYGUI_I_LOG_FILTER_H_
