@@ -4,10 +4,11 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_IMAGE_INFO_H__
-#define __MYGUI_IMAGE_INFO_H__
+#ifndef MYGUI_IMAGE_INFO_H_
+#define MYGUI_IMAGE_INFO_H_
 
 #include "MyGUI_Prerequest.h"
+#include "MyGUI_Types.h"
 
 namespace MyGUI
 {
@@ -47,4 +48,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_IMAGE_INFO_H__
+#endif // MYGUI_IMAGE_INFO_H_
