@@ -4,8 +4,8 @@
  * (See accompanying file COPYING.MIT or copy at http://opensource.org/licenses/MIT)
  */
 
-#ifndef __MYGUI_TAB_ITEM_H__
-#define __MYGUI_TAB_ITEM_H__
+#ifndef MYGUI_TAB_ITEM_H_
+#define MYGUI_TAB_ITEM_H_
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_TextBox.h"
@@ -18,7 +18,7 @@ namespace MyGUI
 		TabItem widget description should be here.
 	*/
 	class MYGUI_EXPORT TabItem :
-		public TextBox // FIXME       (Bug #190)
+        public TextBox // FIXME temporary use TextBox instead of Widget for caption
 	{
 		MYGUI_RTTI_DERIVED( TabItem )
 
@@ -26,20 +26,20 @@ namespace MyGUI
 		TabItem();
 
 		/** Set item caption */
-		virtual void setCaption(const UString& _value);
+		void setCaption(const UString& _value) override;
 		/** Get item caption */
-		virtual const UString& getCaption();
+		const UString& getCaption() const override;
 
 		//! Set button width
 		void setButtonWidth(int _value = DEFAULT);
 
 	protected:
-		virtual void initialiseOverride();
-		virtual void shutdownOverride();
+		void initialiseOverride() override;
+		void shutdownOverride() override;
 
-		virtual void setPropertyOverride(const std::string& _key, const std::string& _value);
+		void setPropertyOverride(const std::string& _key, const std::string& _value) override;
 	};
 
 } // namespace MyGUI
 
-#endif // __MYGUI_TAB_ITEM_H__
+#endif // MYGUI_TAB_ITEM_H_
