@@ -15,7 +15,7 @@
 #include "MyGUI_ISubWidgetText.h"
 #include "MyGUI_ScrollBar.h"
 
-#include <ctype.h>
+#include <cctype>
 
 namespace MyGUI
 {
@@ -65,18 +65,16 @@ namespace MyGUI
 		// FIXME нам нужен фокус клавы
 		setNeedKeyFocus(true);
 
-		///@wskin_child{EditBox, Widget, Client} Клиентская зона.
-		assignWidget(mClient, "Client");
-		if (mClient != nullptr)
+		assignWidget(mScrollViewClient, "Client");
+		if (getClientWidget() != nullptr)
 		{
-			mClient->eventMouseSetFocus += newDelegate(this, &EditBox::notifyMouseSetFocus);
-			mClient->eventMouseLostFocus += newDelegate(this, &EditBox::notifyMouseLostFocus);
-			mClient->eventMouseButtonPressed += newDelegate(this, &EditBox::notifyMousePressed);
-			mClient->eventMouseButtonReleased += newDelegate(this, &EditBox::notifyMouseReleased);
-			mClient->eventMouseDrag += newDelegate(this, &EditBox::notifyMouseDrag);
-			mClient->eventMouseButtonDoubleClick += newDelegate(this, &EditBox::notifyMouseButtonDoubleClick);
-			mClient->eventMouseWheel += newDelegate(this, &EditBox::notifyMouseWheel);
-			setWidgetClient(mClient);
+			getClientWidget()->eventMouseSetFocus += newDelegate(this, &EditBox::notifyMouseSetFocus);
+			getClientWidget()->eventMouseLostFocus += newDelegate(this, &EditBox::notifyMouseLostFocus);
+			getClientWidget()->eventMouseButtonPressed += newDelegate(this, &EditBox::notifyMousePressed);
+			getClientWidget()->eventMouseButtonReleased += newDelegate(this, &EditBox::notifyMouseReleased);
+			getClientWidget()->eventMouseDrag += newDelegate(this, &EditBox::notifyMouseDrag);
+			getClientWidget()->eventMouseButtonDoubleClick += newDelegate(this, &EditBox::notifyMouseButtonDoubleClick);
+			getClientWidget()->eventMouseWheel += newDelegate(this, &EditBox::notifyMouseWheel);
 		}
 
 		///@wskin_child{EditBox, ScrollBar, VScroll} Вертикальная полоса прокрутки.
@@ -94,9 +92,9 @@ namespace MyGUI
 		}
 
 		mClientText = getSubWidgetText();
-		if (mClient != nullptr)
+		if (getClientWidget() != nullptr)
 		{
-			ISubWidgetText* text = mClient->getSubWidgetText();
+			ISubWidgetText* text = getClientWidget()->getSubWidgetText();
 			if (text)
 				mClientText = text;
 		}
@@ -112,7 +110,7 @@ namespace MyGUI
 
 	void EditBox::shutdownOverride()
 	{
-		mClient = nullptr;
+		mScrollViewClient = nullptr;
 		mClientText = nullptr;
 		mVScroll = nullptr;
 		mHScroll = nullptr;
@@ -122,7 +120,7 @@ namespace MyGUI
 
 	void EditBox::notifyMouseSetFocus(Widget* _sender, Widget* _old)
 	{
-		if ((_old == mClient) || (mIsFocus))
+		if ((_old == getClientWidget()) || (mIsFocus))
 			return;
 
 		mIsFocus = true;
@@ -131,7 +129,7 @@ namespace MyGUI
 
 	void EditBox::notifyMouseLostFocus(Widget* _sender, Widget* _new)
 	{
-		if ((_new == mClient) || (!mIsFocus))
+		if ((_new == getClientWidget()) || (!mIsFocus))
 			return;
 
 		mIsFocus = false;
@@ -183,25 +181,25 @@ namespace MyGUI
 		mCursorTimer = 0;
 		mActionMouseTimer = 0;
 
-		size_t Old = mCursorPosition;
+		size_t old = mCursorPosition;
 		IntPoint point(_left, _top);
 		mCursorPosition = mClientText->getCursorPosition(point);
-		if (Old == mCursorPosition)
-			return;
 
-		mClientText->setCursorPosition(mCursorPosition);
+		if (old != mCursorPosition)
+		{
+			mClientText->setCursorPosition(mCursorPosition);
 
-		// если не было выделения
-		if (mStartSelect == ITEM_NONE)
-			mStartSelect = Old;
+			if (mStartSelect == ITEM_NONE)
+				mStartSelect = old;
 
-		// меняем выделение
-		mEndSelect = (size_t)mCursorPosition;
-		if (mStartSelect > mEndSelect)
-			mClientText->setTextSelection(mEndSelect, mStartSelect);
-		else
-			mClientText->setTextSelection(mStartSelect, mEndSelect);
+			mEndSelect = (size_t)mCursorPosition;
+			if (mStartSelect > mEndSelect)
+				mClientText->setTextSelection(mEndSelect, mStartSelect);
+			else
+				mClientText->setTextSelection(mStartSelect, mEndSelect);
 
+			updateViewWithCursor();
+		}
 	}
 
 	void EditBox::notifyMouseButtonDoubleClick(Widget* _sender)
@@ -219,20 +217,20 @@ namespace MyGUI
 		mStartSelect = cursorPosition;
 		mEndSelect = cursorPosition;
 
-		UString text = this->getOnlyText();
-		UString::reverse_iterator iterBack = text.rend() - cursorPosition;
-		UString::iterator iterForw = text.begin() + cursorPosition;
+		UString::utf32string text = this->getOnlyText().asUTF32();
+		UString::utf32string::reverse_iterator iterBack = text.rend() - cursorPosition;
+		UString::utf32string::iterator iterForw = text.begin() + cursorPosition;
 
 		while (iterBack != text.rend())
 		{
-			if (((*iterBack) < 265) && (ispunct(*iterBack) || isspace(*iterBack)))
+			if (((*iterBack) < 256) && (ispunct(*iterBack) || isspace(*iterBack)))
 				break;
 			++iterBack;
 			mStartSelect--;
 		}
 		while (iterForw != text.end())
 		{
-			if (((*iterForw) < 265) && (ispunct(*iterForw) || isspace(*iterForw)))
+			if (((*iterForw) < 256) && (ispunct(*iterForw) || isspace(*iterForw)))
 				break;
 			++iterForw;
 			mEndSelect++;
@@ -291,9 +289,13 @@ namespace MyGUI
 		Base::onKeyLostFocus(_new);
 	}
 
+	bool isWhitespace(const UString::code_point& c) {
+		return c == ' ' || c == '\t';
+	}
+
 	void EditBox::onKeyButtonPressed(KeyCode _key, Char _char)
 	{
-		if (mClientText == nullptr || mClient == nullptr)
+		if (mClientText == nullptr || getClientWidget() == nullptr)
 		{
 			Base::onKeyButtonPressed(_key, _char);
 			return;
@@ -412,7 +414,29 @@ namespace MyGUI
 		{
 			if ((mCursorPosition) < mTextLength)
 			{
-				mCursorPosition ++;
+				if (input.isControlPressed())
+				{
+					if (mModePassword)
+					{
+						mCursorPosition = mTextLength;
+					}
+					else
+					{
+						const UString& text = getRealString();
+						while (mCursorPosition < mTextLength && isWhitespace(text[mCursorPosition]))
+						{
+							mCursorPosition ++;
+						}
+						while (mCursorPosition < mTextLength && !isWhitespace(text[mCursorPosition]))
+						{
+							mCursorPosition ++;
+						}
+					}
+				}
+				else
+				{
+					mCursorPosition ++;
+				}
 				mClientText->setCursorPosition(mCursorPosition);
 				updateSelectText();
 			}
@@ -427,7 +451,29 @@ namespace MyGUI
 		{
 			if (mCursorPosition != 0)
 			{
-				mCursorPosition --;
+				if (input.isControlPressed())
+				{
+					if (mModePassword)
+					{
+						mCursorPosition = 0;
+					}
+					else
+					{
+						const UString& text = getRealString();
+						while (mCursorPosition > 0 && isWhitespace(text[mCursorPosition - 1]))
+						{
+							mCursorPosition --;
+						}
+						while (mCursorPosition > 0 && !isWhitespace(text[mCursorPosition - 1]))
+						{
+							mCursorPosition --;
+						}
+					}
+				}
+				else
+				{
+					mCursorPosition --;
+				}
 				mClientText->setCursorPosition(mCursorPosition);
 				updateSelectText();
 			}
@@ -568,7 +614,7 @@ namespace MyGUI
 		{
 			// на размер окна, но не меньше одной строки
 			IntPoint point = mClientText->getCursorPoint(mCursorPosition);
-			point.top -= (mClient->getHeight() > mClientText->getFontHeight()) ? mClient->getHeight() : mClientText->getFontHeight();
+			point.top -= (getClientWidget()->getHeight() > mClientText->getFontHeight()) ? getClientWidget()->getHeight() : mClientText->getFontHeight();
 			size_t old = mCursorPosition;
 			mCursorPosition = mClientText->getCursorPosition(point);
 			// самая верхняя строчка
@@ -597,7 +643,7 @@ namespace MyGUI
 		{
 			// на размер окна, но не меньше одной строки
 			IntPoint point = mClientText->getCursorPoint(mCursorPosition);
-			point.top += (mClient->getHeight() > mClientText->getFontHeight()) ? mClient->getHeight() : mClientText->getFontHeight();
+			point.top += (getClientWidget()->getHeight() > mClientText->getFontHeight()) ? getClientWidget()->getHeight() : mClientText->getFontHeight();
 			size_t old = mCursorPosition;
 			mCursorPosition = mClientText->getCursorPosition(point);
 			// самая нижняя строчка
@@ -729,7 +775,7 @@ namespace MyGUI
 			if (mActionMouseTimer > EDIT_ACTION_MOUSE_TIMER)
 			{
 				IntPoint mouse = InputManager::getInstance().getMousePositionByLayer();
-				const IntRect& view = mClient->getAbsoluteRect();
+				const IntRect& view = getClientWidget()->getAbsoluteRect();
 				mouse.left -= view.left;
 				mouse.top -= view.top;
 				IntPoint point;
@@ -739,7 +785,7 @@ namespace MyGUI
 				// вверх на одну строчку
 				if ((mouse.top < 0) && (mouse.top > -EDIT_ACTION_MOUSE_ZONE))
 				{
-					if ((mouse.left > 0) && (mouse.left <= mClient->getWidth()))
+					if ((mouse.left > 0) && (mouse.left <= getClientWidget()->getWidth()))
 					{
 						point = mClientText->getCursorPoint(mCursorPosition);
 						point.top -= mClientText->getFontHeight();
@@ -747,9 +793,9 @@ namespace MyGUI
 					}
 				}
 				// вниз на одну строчку
-				else if ((mouse.top > mClient->getHeight()) && (mouse.top < (mClient->getHeight() + EDIT_ACTION_MOUSE_ZONE)))
+				else if ((mouse.top > getClientWidget()->getHeight()) && (mouse.top < (getClientWidget()->getHeight() + EDIT_ACTION_MOUSE_ZONE)))
 				{
-					if ((mouse.left > 0) && (mouse.left <= mClient->getWidth()))
+					if ((mouse.left > 0) && (mouse.left <= getClientWidget()->getWidth()))
 					{
 						point = mClientText->getCursorPoint(mCursorPosition);
 						point.top += mClientText->getFontHeight();
@@ -765,7 +811,7 @@ namespace MyGUI
 					action = true;
 				}
 				// вправо на небольшое расстояние
-				else if ((mouse.left > mClient->getWidth()) && (mouse.left < (mClient->getWidth() + EDIT_ACTION_MOUSE_ZONE)))
+				else if ((mouse.left > getClientWidget()->getWidth()) && (mouse.left < (getClientWidget()->getWidth() + EDIT_ACTION_MOUSE_ZONE)))
 				{
 					point = mClientText->getCursorPoint(mCursorPosition);
 					point.left += (int)EDIT_OFFSET_HORZ_CURSOR;
@@ -780,7 +826,10 @@ namespace MyGUI
 					if (old != mCursorPosition)
 					{
 						mClientText->setCursorPosition(mCursorPosition);
-
+						
+						if (mStartSelect == ITEM_NONE)
+							mStartSelect = old;
+						
 						mEndSelect = (size_t)mCursorPosition;
 						if (mStartSelect > mEndSelect)
 							mClientText->setTextSelection(mEndSelect, mStartSelect);
@@ -903,41 +952,42 @@ namespace MyGUI
 		if (mVectorUndoChangeInfo.empty())
 			return false;
 
-		// сбрасываем выделение
 		resetSelect();
 
-		// сохраняем последние набор отмен
+		// save last undo info
 		VectorChangeInfo info = mVectorUndoChangeInfo.back();
-		// перекидываем последний набор отмен
+		// move undo info to redo
 		mVectorUndoChangeInfo.pop_back();
 		mVectorRedoChangeInfo.push_back(info);
 
-		// берем текст для издевательств
-		UString text = getRealString();
+		UString::utf32string text = getRealString().asUTF32();
 
-		// восстанавливаем последовательность
-		for (VectorChangeInfo::reverse_iterator iter = info.rbegin(); iter != info.rend(); ++iter)
+		// apply undo
+		for (VectorChangeInfo::const_reverse_iterator iter = info.rbegin(); iter != info.rend(); ++iter)
 		{
-			if ((*iter).type == TextCommandInfo::COMMAND_INSERT)
-				text.erase((*iter).start, (*iter).text.size());
-			else if ((*iter).type == TextCommandInfo::COMMAND_ERASE)
-				text.insert((*iter).start, (*iter).text);
-			else
+			const auto& change = *iter;
+			switch (change.type)
 			{
-				mCursorPosition = (*iter).undo;
-				mTextLength = (*iter).length;
+			case TextCommandInfo::COMMAND_INSERT:
+				text.erase(change.start, change.text.size());
+				break;
+			case TextCommandInfo::COMMAND_ERASE:
+				text.insert(change.start, change.text);
+				break;
+			case TextCommandInfo::COMMAND_POSITION:
+				mCursorPosition = change.undo;
+				mTextLength = change.length;
+				break;
 			}
 		}
 
-		// возвращаем текст
-		setRealString(text);
+		setRealString(UString(text));
 
-		// обновляем по позиции
+		// restore cursor position
 		if (mClientText != nullptr)
 			mClientText->setCursorPosition(mCursorPosition);
 		updateSelectText();
 
-		// отсылаем событие о изменении
 		eventEditTextChange(this);
 
 		return true;
@@ -951,39 +1001,40 @@ namespace MyGUI
 		// сбрасываем выделение
 		resetSelect();
 
-		// сохраняем последние набор отмен
+		// save last undo info
 		VectorChangeInfo info = mVectorRedoChangeInfo.back();
-		// перекидываем последний набор отмен
+		// move redo info to undo
 		mVectorRedoChangeInfo.pop_back();
 		mVectorUndoChangeInfo.push_back(info);
 
-		// берем текст для издевательств
-		UString text = getRealString();
+		UString::utf32string text = getRealString().asUTF32();
 
-		// восстанавливаем последовательность
-		for (VectorChangeInfo::iterator iter = info.begin(); iter != info.end(); ++iter)
+		// apply redo
+		for (const auto& change : info)
 		{
-			if ((*iter).type == TextCommandInfo::COMMAND_INSERT)
-				text.insert((*iter).start, (*iter).text);
-			else if ((*iter).type == TextCommandInfo::COMMAND_ERASE)
-				text.erase((*iter).start, (*iter).text.size());
-			else
+			switch (change.type)
 			{
-				mCursorPosition = (*iter).redo;
-				mTextLength = (*iter).length;
+			case TextCommandInfo::COMMAND_INSERT:
+				text.insert(change.start, change.text);
+				break;
+			case TextCommandInfo::COMMAND_ERASE:
+				text.erase(change.start, change.text.size());
+				break;
+			case TextCommandInfo::COMMAND_POSITION:
+				mCursorPosition = change.redo;
+				mTextLength = change.length;
+				break;
 			}
 
 		}
 
-		// возвращаем текст
-		setRealString(text);
+		setRealString(UString(text));
 
-		// обновляем по позиции
+		// restore cursor position
 		if (mClientText != nullptr)
 			mClientText->setCursorPosition(mCursorPosition);
 		updateSelectText();
 
-		// отсылаем событие о изменении
 		eventEditTextChange(this);
 
 		return true;
@@ -1006,7 +1057,7 @@ namespace MyGUI
 	}
 
 	// возвращает текст
-	UString EditBox::getTextInterval(size_t _start, size_t _count)
+	UString EditBox::getTextInterval(size_t _start, size_t _count) const
 	{
 		// подстраховка
 		if (_start > mTextLength) _start = mTextLength;
@@ -1134,7 +1185,7 @@ namespace MyGUI
 		_setTextColour(start, end - start, _colour, _history);
 	}
 
-	UString EditBox::getTextSelection()
+	UString EditBox::getTextSelection() const
 	{
 		if ( !isTextSelection())
 			return "";
@@ -1459,7 +1510,7 @@ namespace MyGUI
 		}
 	}
 
-	const UString& EditBox::getRealString()
+	const UString& EditBox::getRealString() const
 	{
 		if (mModePassword)
 			return mPasswordText;
@@ -1553,7 +1604,7 @@ namespace MyGUI
 		setText(_value, false);
 	}
 
-	const UString& EditBox::getCaption()
+	const UString& EditBox::getCaption() const
 	{
 		return getRealString();
 	}
@@ -1608,14 +1659,14 @@ namespace MyGUI
 			mClientText->setTextColour(_value);
 	}
 
-	IntCoord EditBox::getTextRegion()
+	IntCoord EditBox::getTextRegion() const
 	{
 		if (mClientText != nullptr)
 			return mClientText->getCoord();
 		return Base::getTextRegion();
 	}
 
-	IntSize EditBox::getTextSize()
+	IntSize EditBox::getTextSize() const
 	{
 		if (mClientText != nullptr)
 			return mClientText->getTextSize();
@@ -1721,6 +1772,11 @@ namespace MyGUI
 		eraseView();
 	}
 
+	int EditBox::getFontHeight() const
+	{
+		return (nullptr == mClientText) ? 0 : mClientText->getFontHeight();
+	}
+
 	void EditBox::updateView()
 	{
 		updateScrollSize();
@@ -1736,7 +1792,7 @@ namespace MyGUI
 
 	void EditBox::updateCursorPosition()
 	{
-		if (mClientText == nullptr || mClient == nullptr)
+		if (mClientText == nullptr || getClientWidget() == nullptr)
 			return;
 
 		// размер контекста текста
@@ -1752,7 +1808,7 @@ namespace MyGUI
 		cursor.right ++;
 
 		// абсолютные координаты вью
-		const IntRect& view = mClient->getAbsoluteRect();
+		const IntRect& view = getClientWidget()->getAbsoluteRect();
 
 		// проверяем и показываем курсор
 		if (!view.inside(cursor))
@@ -1815,42 +1871,42 @@ namespace MyGUI
 			mClientText->setViewOffset(_point);
 	}
 
-	IntSize EditBox::getViewSize()
+	IntSize EditBox::getViewSize() const
 	{
 		if (mClientText != nullptr)
 			return mClientText->getSize();
 		return ScrollViewBase::getViewSize();
 	}
 
-	IntSize EditBox::getContentSize()
+	IntSize EditBox::getContentSize() const
 	{
 		if (mClientText != nullptr)
 			return mClientText->getTextSize();
 		return ScrollViewBase::getContentSize();
 	}
 
-	size_t EditBox::getVScrollPage()
+	size_t EditBox::getVScrollPage() const
 	{
 		if (mClientText != nullptr)
 			return (size_t)mClientText->getFontHeight();
 		return ScrollViewBase::getVScrollPage();
 	}
 
-	size_t EditBox::getHScrollPage()
+	size_t EditBox::getHScrollPage() const
 	{
 		if (mClientText != nullptr)
 			return (size_t)mClientText->getFontHeight();
 		return ScrollViewBase::getHScrollPage();
 	}
 
-	IntPoint EditBox::getContentPosition()
+	IntPoint EditBox::getContentPosition() const
 	{
 		if (mClientText != nullptr)
 			return mClientText->getViewOffset();
 		return ScrollViewBase::getContentPosition();
 	}
 
-	Align EditBox::getContentAlign()
+	Align EditBox::getContentAlign() const
 	{
 		if (mClientText != nullptr)
 			return mClientText->getTextAlign();
@@ -1897,7 +1953,7 @@ namespace MyGUI
 		setText(TextIterator::toTagsString(_text), false);
 	}
 
-	UString EditBox::getOnlyText()
+	UString EditBox::getOnlyText() const
 	{
 		return TextIterator::getOnlyText(getRealString());
 	}
@@ -1946,12 +2002,12 @@ namespace MyGUI
 		mModeStatic = _value;
 		resetSelect();
 
-		if (mClient != nullptr)
+		if (getClientWidget() != nullptr)
 		{
 			if (mModeStatic)
-				mClient->setPointer("");
+				getClientWidget()->setPointer("");
 			else
-				mClient->setPointer(mOriginalPointer);
+				getClientWidget()->setPointer(mOriginalPointer);
 		}
 	}
 
@@ -1978,7 +2034,7 @@ namespace MyGUI
 		return mVRange + 1;
 	}
 
-	size_t EditBox::getVScrollPosition()
+	size_t EditBox::getVScrollPosition() const
 	{
 		return mClientText == nullptr ? 0 : mClientText->getViewOffset().top;
 	}
@@ -2005,7 +2061,7 @@ namespace MyGUI
 		return mHRange + 1;
 	}
 
-	size_t EditBox::getHScrollPosition()
+	size_t EditBox::getHScrollPosition() const
 	{
 		return mClientText == nullptr ? 0 : mClientText->getViewOffset().left;
 	}
@@ -2027,7 +2083,7 @@ namespace MyGUI
 			mHScroll->setScrollPosition(point.left);
 	}
 
-	bool EditBox::getInvertSelected()
+	bool EditBox::getInvertSelected() const
 	{
 		return mClientText == nullptr ? false : mClientText->getInvertSelected();
 	}
@@ -2076,11 +2132,11 @@ namespace MyGUI
 		else if (_key == "Static")
 			setEditStatic(utility::parseValue<bool>(_value));
 
-		/// @wproperty{EditBox, VisibleVScroll, bool} Видимость вертикальной полосы прокрутки.
+		/// @wproperty{EditBox, VisibleVScroll, bool} Vertical scroll bar visibility.
 		else if (_key == "VisibleVScroll")
 			setVisibleVScroll(utility::parseValue<bool>(_value));
 
-		/// @wproperty{EditBox, VisibleHScroll, bool} Видимость горизонтальной полосы прокрутки.
+		/// @wproperty{ItemBox, VisibleHScroll, bool} Horizontal scroll bar visibility.
 		else if (_key == "VisibleHScroll")
 			setVisibleHScroll(utility::parseValue<bool>(_value));
 
@@ -2175,21 +2231,6 @@ namespace MyGUI
 		return mTabPrinting;
 	}
 
-	void EditBox::setPosition(int _left, int _top)
-	{
-		setPosition(IntPoint(_left, _top));
-	}
-
-	void EditBox::setSize(int _width, int _height)
-	{
-		setSize(IntSize(_width, _height));
-	}
-
-	void EditBox::setCoord(int _left, int _top, int _width, int _height)
-	{
-		setCoord(IntCoord(_left, _top, _width, _height));
-	}
-
 	bool EditBox::isVisibleVScroll() const
 	{
 		return mVisibleVScroll;
