@@ -20,8 +20,7 @@ namespace MyGUI
 	const float INPUT_DELAY_FIRST_KEY = 0.4f;
 	const float INPUT_INTERVAL_KEY = 0.05f;
 
-	template <> InputManager* Singleton<InputManager>::msInstance = nullptr;
-	template <> const char* Singleton<InputManager>::mClassTypeName = "InputManager";
+	MYGUI_SINGLETON_DEFINITION(InputManager);
 
 	InputManager::InputManager() :
 		mWidgetMouseFocus(nullptr),
@@ -35,7 +34,8 @@ namespace MyGUI
 		mFirstPressKey(false),
 		mTimerKey(0.0f),
 		mOldAbsZ(0),
-		mIsInitialise(false)
+		mIsInitialise(false),
+		mSingletonHolder(this)
 	{
 		resetMouseCaptureWidget();
 	}
@@ -45,9 +45,9 @@ namespace MyGUI
 		MYGUI_ASSERT(!mIsInitialise, getClassTypeName() << " initialised twice");
 		MYGUI_LOG(Info, "* Initialise: " << getClassTypeName());
 
-		mWidgetMouseFocus = 0;
-		mWidgetKeyFocus = 0;
-		mLayerMouseFocus = 0;
+		mWidgetMouseFocus = nullptr;
+		mWidgetKeyFocus = nullptr;
+		mLayerMouseFocus = nullptr;
 		for (int i = MouseButton::Button0; i < MouseButton::MAX; ++i)
 		{
 			mMouseCapture[i] = false;
@@ -99,7 +99,8 @@ namespace MyGUI
 
 		if (isCaptureMouse())
 		{
-			if (isFocusMouse())
+			bool isFocus = isFocusMouse();
+			if (isFocus)
 			{
 				if (mLayerMouseFocus != nullptr)
 				{
@@ -111,12 +112,8 @@ namespace MyGUI
 					}
 				}
 			}
-			else
-			{
-				resetMouseCaptureWidget();
-			}
 
-			return true;
+			return isFocus;
 		}
 
 		Widget* old_mouse_focus = mWidgetMouseFocus;
@@ -200,7 +197,10 @@ namespace MyGUI
 
 		if ((item != nullptr) && (item->getInheritedEnabled()))
 		{
-			item->_riseMouseMove(_absx, _absy);
+			MyGUI::IntPoint point (_absx, _absy);
+			if (mLayerMouseFocus != nullptr)
+				point = mLayerMouseFocus->getPosition(_absx, _absy);
+			item->_riseMouseMove(point.left, point.top);
 			item->_riseMouseSetFocus(mWidgetMouseFocus);
 		}
 
@@ -221,16 +221,17 @@ namespace MyGUI
 	{
 		injectMouseMove(_absx, _absy, mOldAbsZ);
 
-		Widget* old_key_focus = mWidgetKeyFocus;
+		if (MouseButton::None != _id && MouseButton::MAX != _id)
+		{
+			// start capture
+			mMouseCapture[_id.getValue()] = true;
+		}
 
 		// если мы щелкнули не на гуй
 		if (!isFocusMouse())
 		{
 			resetKeyFocusWidget();
 
-			if (old_key_focus != mWidgetKeyFocus)
-				eventChangeKeyFocus(mWidgetKeyFocus);
-
 			return false;
 		}
 
@@ -241,8 +242,6 @@ namespace MyGUI
 
 		if (MouseButton::None != _id && MouseButton::MAX != _id)
 		{
-			// start capture
-			mMouseCapture[_id.getValue()] = true;
 			// remember last pressed position
 			if (mLayerMouseFocus != nullptr)
 			{
@@ -261,7 +260,10 @@ namespace MyGUI
 
 		if (isFocusMouse())
 		{
-			mWidgetMouseFocus->_riseMouseButtonPressed(_absx, _absy, _id);
+			IntPoint point (_absx, _absy);
+			if (mLayerMouseFocus != nullptr)
+				point = mLayerMouseFocus->getPosition(_absx, _absy);
+			mWidgetMouseFocus->_riseMouseButtonPressed(point.left, point.top, _id);
 
 			// после пресса может сброситься
 			if (mWidgetMouseFocus)
@@ -285,30 +287,30 @@ namespace MyGUI
 			}
 		}
 
-		if (old_key_focus != mWidgetKeyFocus)
-			eventChangeKeyFocus(mWidgetKeyFocus);
-
 		return true;
 	}
 
 	bool InputManager::injectMouseRelease(int _absx, int _absy, MouseButton _id)
 	{
+		if (_id != MouseButton::None && _id != MouseButton::MAX)
+		{
+			if (mMouseCapture[_id.getValue()])
+			{
+				// drop capture
+				mMouseCapture[_id.getValue()] = false;
+			}
+		}
+
 		if (isFocusMouse())
 		{
 			// если активный элемент заблокирован
 			if (!mWidgetMouseFocus->getInheritedEnabled())
 				return true;
 
-			if (_id != MouseButton::None && _id != MouseButton::MAX)
-			{
-				if (mMouseCapture[_id.getValue()])
-				{
-					// drop capture
-					mMouseCapture[_id.getValue()] = false;
-				}
-			}
-
-			mWidgetMouseFocus->_riseMouseButtonReleased(_absx, _absy, _id);
+			IntPoint point (_absx, _absy);
+			if (mLayerMouseFocus != nullptr)
+				point = mLayerMouseFocus->getPosition(_absx, _absy);
+			mWidgetMouseFocus->_riseMouseButtonReleased(point.left, point.top, _id);
 
 			// после вызова, виджет может быть сброшен
 			if (nullptr != mWidgetMouseFocus)
@@ -392,51 +394,52 @@ namespace MyGUI
 		if (_widget == mWidgetKeyFocus)
 			return;
 
-		//-------------------------------------------------------------------------------------//
-		// новый вид рутового фокуса
-		Widget* save_widget = nullptr;
+		Widget* oldKeyFocus = mWidgetKeyFocus;
+		mWidgetKeyFocus = nullptr;
 
-		// спускаемся по новому виджету и устанавливаем рутовый фокус
-		Widget* root_focus = _widget;
-		while (root_focus != nullptr)
+		Widget* sharedRootFocus = nullptr; // possible shared parent for both old and new widget
+
+		// recursively set root key focus
+		Widget* rootFocus = _widget;
+		while (rootFocus != nullptr)
 		{
-			if (root_focus->getRootKeyFocus())
+			if (rootFocus->getRootKeyFocus())
 			{
-				save_widget = root_focus;
+				sharedRootFocus = rootFocus;
 				break;
 			}
 
-			root_focus->_setRootKeyFocus(true);
-			root_focus->_riseKeyChangeRootFocus(true);
-			root_focus = root_focus->getParent();
+			rootFocus->_setRootKeyFocus(true);
+			rootFocus->_riseKeyChangeRootFocus(true);
+			rootFocus = rootFocus->getParent();
 		}
 
-		// спускаемся по старому виджету и сбрасываем фокус
-		root_focus = mWidgetKeyFocus;
-		while (root_focus != nullptr)
+		// recursively reset root key focus
+		rootFocus = oldKeyFocus;
+		while (rootFocus != nullptr)
 		{
-			if (root_focus == save_widget)
+			if (rootFocus == sharedRootFocus)
 				break;
 
-			root_focus->_setRootKeyFocus(false);
-			root_focus->_riseKeyChangeRootFocus(false);
-			root_focus = root_focus->getParent();
+			rootFocus->_setRootKeyFocus(false);
+			rootFocus->_riseKeyChangeRootFocus(false);
+			rootFocus = rootFocus->getParent();
 		}
 		//-------------------------------------------------------------------------------------//
 
-		// сбрасываем старый
-		if (mWidgetKeyFocus)
+		mWidgetKeyFocus = _widget;
+
+		if (oldKeyFocus)
 		{
-			mWidgetKeyFocus->_riseKeyLostFocus(_widget);
+			oldKeyFocus->_riseKeyLostFocus(_widget);
 		}
 
-		// устанавливаем новый
-		if (_widget && _widget->getNeedKeyFocus())
+		if (_widget)
 		{
 			_widget->_riseKeySetFocus(mWidgetKeyFocus);
 		}
 
-		mWidgetKeyFocus = _widget;
+		eventChangeKeyFocus(mWidgetKeyFocus);
 	}
 
 	void InputManager::_resetMouseFocusWidget()
@@ -444,7 +447,7 @@ namespace MyGUI
 		Widget* mouseFocus = mWidgetMouseFocus;
 		mWidgetMouseFocus = nullptr;
 
-		// спускаемся по старому виджету и сбрасываем фокус
+		// recursively reset old widget focus
 		Widget* root_focus = mouseFocus;
 		while (root_focus != nullptr)
 		{
@@ -458,7 +461,10 @@ namespace MyGUI
 			if (mMouseCapture[i])
 			{
 				mMouseCapture[i] = false;
-				mouseFocus->_riseMouseButtonReleased(mLastPressed[i].left, mLastPressed[i].top, MouseButton::Enum(i));
+				if (nullptr != mouseFocus)
+				{
+					mouseFocus->_riseMouseButtonReleased(mLastPressed[i].left, mLastPressed[i].top, MouseButton::Enum(i));
+				}
 			}
 		}
 
@@ -466,6 +472,9 @@ namespace MyGUI
 		{
 			mouseFocus->_riseMouseLostFocus(nullptr);
 		}
+
+		if (mouseFocus != mWidgetMouseFocus)
+			eventChangeMouseFocus(mWidgetMouseFocus);
 	}
 
 	// удаляем данный виджет из всех возможных мест
@@ -478,9 +487,7 @@ namespace MyGUI
 			_resetMouseFocusWidget();
 
 		if (_widget == mWidgetKeyFocus)
-		{
-			mWidgetKeyFocus = nullptr;
-		}
+			resetKeyFocusWidget();
 
 		// ручками сбрасываем, чтобы не менять фокусы
 		for (VectorWidgetPtr::iterator iter = mVectorModalRootWidget.begin(); iter != mVectorModalRootWidget.end(); ++iter)
@@ -596,7 +603,7 @@ namespace MyGUI
 			setKeyFocusWidget(nullptr);
 	}
 
-	IntPoint InputManager::getMousePositionByLayer()
+	IntPoint InputManager::getMousePositionByLayer() const
 	{
 		if (mLayerMouseFocus != nullptr)
 			return mLayerMouseFocus->getPosition(mMousePosition.left, mMousePosition.top);
