@@ -17,6 +17,7 @@ namespace MyGUI
 
 	ListBox::ListBox() :
 		mWidgetScroll(nullptr),
+		mActivateOnClick(false),
 		mHeightLine(1),
 		mTopIndex(0),
 		mOffsetTop(0),
@@ -24,8 +25,7 @@ namespace MyGUI
 		mLastRedrawLine(0),
 		mIndexSelect(ITEM_NONE),
 		mLineActive(ITEM_NONE),
-		mNeedVisibleScroll(true),
-		mClient(nullptr)
+		mNeedVisibleScroll(true)
 	{
 	}
 
@@ -46,15 +46,12 @@ namespace MyGUI
 		if (mHeightLine < 1)
 			mHeightLine = 1;
 
-		///@wskin_child{ListBox, Widget, Client} Клиентская зона.
-		assignWidget(mClient, "Client");
-		if (mClient != nullptr)
+		if (getClientWidget() != nullptr)
 		{
-			mClient->eventMouseButtonPressed += newDelegate(this, &ListBox::notifyMousePressed);
-			mClient->eventMouseButtonReleased += newDelegate(this, &ListBox::notifyMouseButtonReleased);
-			mClient->eventKeyButtonPressed += newDelegate(this, &ListBox::notifyKeyButtonPressed);
-			mClient->eventKeyButtonReleased += newDelegate(this, &ListBox::notifyKeyButtonReleased);
-			setWidgetClient(mClient);
+			getClientWidget()->eventMouseButtonPressed += newDelegate(this, &ListBox::notifyMousePressed);
+			getClientWidget()->eventMouseButtonReleased += newDelegate(this, &ListBox::notifyMouseButtonReleased);
+			getClientWidget()->eventKeyButtonPressed += newDelegate(this, &ListBox::notifyKeyButtonPressed);
+			getClientWidget()->eventKeyButtonReleased += newDelegate(this, &ListBox::notifyKeyButtonReleased);
 		}
 
 		///@wskin_child{ListBox, ScrollBar, VScroll} Вертикальная полоса прокрутки.
@@ -63,7 +60,6 @@ namespace MyGUI
 		{
 			mWidgetScroll->eventScrollChangePosition += newDelegate(this, &ListBox::notifyScrollChangePosition);
 			mWidgetScroll->setScrollPage((size_t)mHeightLine);
-			mWidgetScroll->setScrollViewPage((size_t)mHeightLine);
 		}
 
 		updateScroll();
@@ -73,7 +69,6 @@ namespace MyGUI
 	void ListBox::shutdownOverride()
 	{
 		mWidgetScroll = nullptr;
-		mClient = nullptr;
 
 		Base::shutdownOverride();
 	}
@@ -122,15 +117,11 @@ namespace MyGUI
 		}
 		else if (_key == KeyCode::Home)
 		{
-			if (sel != 0)
-				sel = 0;
+			sel = 0;
 		}
 		else if (_key == KeyCode::End)
 		{
-			if (sel != (getItemCount() - 1))
-			{
-				sel = getItemCount() - 1;
-			}
+			sel = getItemCount() - 1;
 		}
 		else if (_key == KeyCode::PageUp)
 		{
@@ -239,49 +230,18 @@ namespace MyGUI
 
 	void ListBox::notifyMousePressed(Widget* _sender, int _left, int _top, MouseButton _id)
 	{
-		if (MouseButton::Left == _id)
-		{
-			// если выделен клиент, то сбрасываем
-			if (_sender == _getClientWidget())
-			{
-				if (mIndexSelect != ITEM_NONE)
-				{
-					_selectIndex(mIndexSelect, false);
-					mIndexSelect = ITEM_NONE;
-					eventListChangePosition(this, mIndexSelect);
-				}
-				eventListMouseItemActivate(this, mIndexSelect);
-
-				// если не клиент, то просчитывам
-			}
-			// ячейка может быть скрыта
-			else if (_sender->getVisible())
-			{
-
-#if MYGUI_DEBUG_MODE == 1
-				_checkMapping("ListBox::notifyMousePressed");
-				MYGUI_ASSERT_RANGE(*_sender->_getInternalData<size_t>(), mWidgetLines.size(), "ListBox::notifyMousePressed");
-				MYGUI_ASSERT_RANGE(*_sender->_getInternalData<size_t>() + mTopIndex, mItemsInfo.size(), "ListBox::notifyMousePressed");
-#endif
-
-				size_t index = *_sender->_getInternalData<size_t>() + mTopIndex;
-
-				if (mIndexSelect != index)
-				{
-					_selectIndex(mIndexSelect, false);
-					_selectIndex(index, true);
-					mIndexSelect = index;
-					eventListChangePosition(this, mIndexSelect);
-				}
-				eventListMouseItemActivate(this, mIndexSelect);
-			}
-
-			_resetContainer(true);
-		}
+		if (MouseButton::Left == _id && !mActivateOnClick)
+			_activateItem(_sender);
 
 		eventNotifyItem(this, IBNotifyItemData(getIndexByWidget(_sender), IBNotifyItemData::MousePressed, _left, _top, _id));
 	}
 
+	void ListBox::notifyMouseClick(MyGUI::Widget* _sender)
+	{
+		if (mActivateOnClick)
+			_activateItem(_sender);
+	}
+
 	void ListBox::notifyMouseDoubleClick(Widget* _sender)
 	{
 		if (mIndexSelect != ITEM_NONE)
@@ -322,18 +282,19 @@ namespace MyGUI
 			{
 				mWidgetScroll->setVisible(false);
 				// увеличиваем клиентскую зону на ширину скрола
-				if (mClient != nullptr)
-					mClient->setSize(mClient->getWidth() + mWidgetScroll->getWidth(), mClient->getHeight());
+				if (getClientWidget() != nullptr)
+					getClientWidget()->setSize(getClientWidget()->getWidth() + mWidgetScroll->getWidth(), getClientWidget()->getHeight());
 			}
 		}
 		else if (!mWidgetScroll->getVisible())
 		{
-			if (mClient != nullptr)
-				mClient->setSize(mClient->getWidth() - mWidgetScroll->getWidth(), mClient->getHeight());
+			if (getClientWidget() != nullptr)
+				getClientWidget()->setSize(getClientWidget()->getWidth() - mWidgetScroll->getWidth(), getClientWidget()->getHeight());
 			mWidgetScroll->setVisible(true);
 		}
 
 		mWidgetScroll->setScrollRange(mRangeIndex + 1);
+		mWidgetScroll->setScrollViewPage(_getClientWidget()->getHeight());
 		if (!mItemsInfo.empty())
 			mWidgetScroll->setTrackSize(mWidgetScroll->getLineSize() * _getClientWidget()->getHeight() / mHeightLine / (int)mItemsInfo.size());
 	}
@@ -365,6 +326,7 @@ namespace MyGUI
 				// подписываемся на всякие там события
 				line->eventMouseButtonPressed += newDelegate(this, &ListBox::notifyMousePressed);
 				line->eventMouseButtonReleased += newDelegate(this, &ListBox::notifyMouseButtonReleased);
+				line->eventMouseButtonClick += newDelegate(this, &ListBox::notifyMouseClick);
 				line->eventMouseButtonDoubleClick += newDelegate(this, &ListBox::notifyMouseDoubleClick);
 				line->eventMouseWheel += newDelegate(this, &ListBox::notifyMouseWheel);
 				line->eventKeyButtonPressed += newDelegate(this, &ListBox::notifyKeyButtonPressed);
@@ -745,7 +707,7 @@ namespace MyGUI
 			return false;
 
 		// если мы внизу и нам нужен целый
-		if ((_getClientWidget()->getHeight() < (offset + mHeightLine)) && (_fill))
+		if (_getClientWidget()->getHeight() < (offset + mHeightLine) && _fill)
 			return false;
 
 		return true;
@@ -790,7 +752,7 @@ namespace MyGUI
 		_redrawItem(_index);
 	}
 
-	const UString& ListBox::getItemNameAt(size_t _index)
+	const UString& ListBox::getItemNameAt(size_t _index) const
 	{
 		MYGUI_ASSERT_RANGE(_index, mItemsInfo.size(), "ListBox::getItemNameAt");
 		return mItemsInfo[_index].first;
@@ -938,16 +900,11 @@ namespace MyGUI
 		return ITEM_NONE;
 	}
 
-	int ListBox::getOptimalHeight()
+	int ListBox::getOptimalHeight() const
 	{
 		return (int)((mCoord.height - _getClientWidget()->getHeight()) + (mItemsInfo.size() * mHeightLine));
 	}
 
-	Widget* ListBox::_getClientWidget()
-	{
-		return mClient == nullptr ? this : mClient;
-	}
-
 	size_t ListBox::getItemCount() const
 	{
 		return mItemsInfo.size();
@@ -996,27 +953,12 @@ namespace MyGUI
 		return isItemVisibleAt(mIndexSelect, _fill);
 	}
 
-	void ListBox::setPosition(int _left, int _top)
+	size_t ListBox::_getItemIndex(Widget* _item) const
 	{
-		setPosition(IntPoint(_left, _top));
-	}
-
-	void ListBox::setSize(int _width, int _height)
-	{
-		setSize(IntSize(_width, _height));
-	}
-
-	void ListBox::setCoord(int _left, int _top, int _width, int _height)
-	{
-		setCoord(IntCoord(_left, _top, _width, _height));
-	}
-
-	size_t ListBox::_getItemIndex(Widget* _item)
-	{
-		for (VectorButton::iterator iter = mWidgetLines.begin(); iter != mWidgetLines.end(); ++iter)
+		for (const auto& line : mWidgetLines)
 		{
-			if ((*iter) == _item)
-				return *(*iter)->_getInternalData<size_t>() + mTopIndex;
+			if (line == _item)
+				return *line->_getInternalData<size_t>() + mTopIndex;
 		}
 		return ITEM_NONE;
 	}
@@ -1029,8 +971,8 @@ namespace MyGUI
 		if (!_update)
 		{
 			WidgetManager& instance = WidgetManager::getInstance();
-			for (VectorButton::iterator iter = mWidgetLines.begin(); iter != mWidgetLines.end(); ++iter)
-				instance.unlinkFromUnlinkers(*iter);
+			for (const auto& line : mWidgetLines)
+				instance.unlinkFromUnlinkers(line);
 		}
 	}
 
@@ -1039,7 +981,8 @@ namespace MyGUI
 		// не коментировать
 		if (_key == "AddItem")
 			addItem(_value);
-
+		else if (_key == "ActivateOnClick")
+			mActivateOnClick = utility::parseBool(_value);
 		else
 		{
 			Base::setPropertyOverride(_key, _value);
@@ -1049,7 +992,47 @@ namespace MyGUI
 		eventChangeProperty(this, _key, _value);
 	}
 
-	size_t ListBox::_getItemCount()
+	void ListBox::_activateItem(MyGUI::Widget* _sender)
+	{
+		// если выделен клиент, то сбрасываем
+		if (_sender == _getClientWidget())
+		{
+			if (mIndexSelect != ITEM_NONE)
+			{
+				_selectIndex(mIndexSelect, false);
+				mIndexSelect = ITEM_NONE;
+				eventListChangePosition(this, mIndexSelect);
+			}
+			eventListMouseItemActivate(this, mIndexSelect);
+
+			// если не клиент, то просчитывам
+		}
+		// ячейка может быть скрыта
+		else if (_sender->getVisible())
+		{
+
+#if MYGUI_DEBUG_MODE == 1
+			_checkMapping("ListBox::notifyMousePressed");
+			MYGUI_ASSERT_RANGE(*_sender->_getInternalData<size_t>(), mWidgetLines.size(), "ListBox::notifyMousePressed");
+			MYGUI_ASSERT_RANGE(*_sender->_getInternalData<size_t>() + mTopIndex, mItemsInfo.size(), "ListBox::notifyMousePressed");
+#endif
+
+			size_t index = *_sender->_getInternalData<size_t>() + mTopIndex;
+
+			if (mIndexSelect != index)
+			{
+				_selectIndex(mIndexSelect, false);
+				_selectIndex(index, true);
+				mIndexSelect = index;
+				eventListChangePosition(this, mIndexSelect);
+			}
+			eventListMouseItemActivate(this, mIndexSelect);
+		}
+
+		_resetContainer(true);
+	}
+
+	size_t ListBox::_getItemCount() const
 	{
 		return getItemCount();
 	}
@@ -1069,14 +1052,14 @@ namespace MyGUI
 		setItemNameAt(_index, _name);
 	}
 
-	const UString& ListBox::_getItemNameAt(size_t _index)
+	const UString& ListBox::_getItemNameAt(size_t _index) const
 	{
 		return getItemNameAt(_index);
 	}
 
-	size_t ListBox::getIndexByWidget(Widget* _widget)
+	size_t ListBox::getIndexByWidget(Widget* _widget) const
 	{
-		if (_widget == mClient)
+		if (_widget == getClientWidget())
 			return ITEM_NONE;
 		return *_widget->_getInternalData<size_t>() + mTopIndex;
 	}
@@ -1103,13 +1086,18 @@ namespace MyGUI
 		eventNotifyItem(this, IBNotifyItemData(ITEM_NONE, IBNotifyItemData::KeyReleased, _key));
 	}
 
+	void ListBox::setActivateOnClick(bool activateOnClick)
+	{
+		mActivateOnClick = activateOnClick;
+	}
+
 	Widget* ListBox::getWidgetByIndex(size_t _index)
 	{
 		if (_index == MyGUI::ITEM_NONE)
 			return nullptr;
 
 		// индекс в нашем массиве
-		size_t index = _index + (size_t)mTopIndex;
+		size_t index = _index - (size_t)mTopIndex;
 
 		if (index < mWidgetLines.size())
 			return mWidgetLines[index];
