@@ -13,7 +13,7 @@ namespace MyGUI
 	//--------------------------------------------------------------------------
 	UString::_base_iterator::_base_iterator()
 	{
-		mString = 0;
+		mString = nullptr;
 	}
 	//--------------------------------------------------------------------------
 	void UString::_base_iterator::_seekFwd( size_type c )
@@ -100,16 +100,19 @@ namespace MyGUI
 	//--------------------------------------------------------------------------
 	//--------------------------------------------------------------------------
 	//--------------------------------------------------------------------------
-	UString::_fwd_iterator::_fwd_iterator()
-	{
-
-	}
+	UString::_fwd_iterator::_fwd_iterator() = default;
 	//--------------------------------------------------------------------------
 	UString::_fwd_iterator::_fwd_iterator( const _fwd_iterator& i )
 	{
 		_become( i );
 	}
 	//--------------------------------------------------------------------------
+	UString::_fwd_iterator& UString::_fwd_iterator::operator=( const _fwd_iterator& i )
+	{
+		_become( i );
+		return *this;
+	}
+	//--------------------------------------------------------------------------
 	UString::_fwd_iterator& UString::_fwd_iterator::operator++()
 	{
 		_seekFwd( 1 );
@@ -211,16 +214,19 @@ namespace MyGUI
 	//--------------------------------------------------------------------------
 	//--------------------------------------------------------------------------
 	//--------------------------------------------------------------------------
-	UString::_const_fwd_iterator::_const_fwd_iterator()
-	{
-
-	}
+	UString::_const_fwd_iterator::_const_fwd_iterator() = default;
 	//--------------------------------------------------------------------------
 	UString::_const_fwd_iterator::_const_fwd_iterator( const _const_fwd_iterator& i )
 	{
 		_become( i );
 	}
 	//--------------------------------------------------------------------------
+	UString::_const_fwd_iterator& UString::_const_fwd_iterator::operator=( const _const_fwd_iterator& i )
+	{
+		_become( i );
+		return *this;
+	}
+	//--------------------------------------------------------------------------
 	UString::_const_fwd_iterator::_const_fwd_iterator( const _fwd_iterator& i )
 	{
 		_become( i );
@@ -322,10 +328,7 @@ namespace MyGUI
 	//--------------------------------------------------------------------------
 	//--------------------------------------------------------------------------
 	//--------------------------------------------------------------------------
-	UString::_rev_iterator::_rev_iterator()
-	{
-
-	}
+	UString::_rev_iterator::_rev_iterator() = default;
 	//--------------------------------------------------------------------------
 	UString::_rev_iterator::_rev_iterator( const _rev_iterator& i )
 	{
@@ -411,10 +414,7 @@ namespace MyGUI
 	//--------------------------------------------------------------------------
 	//--------------------------------------------------------------------------
 	//--------------------------------------------------------------------------
-	UString::_const_rev_iterator::_const_rev_iterator()
-	{
-
-	}
+	UString::_const_rev_iterator::_const_rev_iterator() = default;
 	//--------------------------------------------------------------------------
 	UString::_const_rev_iterator::_const_rev_iterator( const _const_rev_iterator& i )
 	{
@@ -578,6 +578,12 @@ namespace MyGUI
 		assign( str );
 	}
 	//--------------------------------------------------------------------------
+	UString::UString( const utf32string & str )
+	{
+		_init();
+		assign( str );
+	}
+	//--------------------------------------------------------------------------
 	UString::~UString()
 	{
 		_cleanBuffer();
@@ -958,6 +964,15 @@ namespace MyGUI
 		return *this;
 	}
 
+	UString& UString::assign( const utf32string& str )
+	{
+		for (const auto& character : str)
+		{
+			push_back(character);
+		}
+		return *this;
+	}
+
 	UString& UString::assign( const char* c_str )
 	{
 		std::string tmp( c_str );
@@ -1914,14 +1929,14 @@ namespace MyGUI
 
 	void UString::_init()
 	{
-		m_buffer.mVoidBuffer = 0;
+		m_buffer.mVoidBuffer = nullptr;
 		m_bufferType = bt_none;
 		m_bufferSize = 0;
 	}
 
 	void UString::_cleanBuffer() const
 	{
-		if ( m_buffer.mVoidBuffer != 0 ) {
+		if ( m_buffer.mVoidBuffer != nullptr ) {
 			switch ( m_bufferType ) {
 				case bt_string:
 					delete m_buffer.mStrBuffer;
@@ -1933,14 +1948,13 @@ namespace MyGUI
 					delete m_buffer.mUTF32StrBuffer;
 					break;
 				case bt_none: // under the worse of circumstances, this is all we can do, and hope it works out
-				default:
 					//delete m_buffer.mVoidBuffer;
 					// delete void* is undefined, don't do that
 					assert("This should never happen - mVoidBuffer should never contain something if we "
 						"don't know the type");
 					break;
 			}
-			m_buffer.mVoidBuffer = 0;
+			m_buffer.mVoidBuffer = nullptr;
 			m_bufferSize = 0;
 			m_bufferType = bt_none;
 		}
