@@ -15,12 +15,11 @@ namespace tools
 {
 
 	class MYGUI_EXPORT_DLL ColourManager :
-		public MyGUI::Singleton<ColourManager>,
 		public sigslot::has_slots<>
 	{
+		MYGUI_SINGLETON_DECLARATION(ColourManager);
 	public:
 		ColourManager();
-		virtual ~ColourManager();
 
 		void initialise();
 		void shutdown();
