@@ -20,7 +20,6 @@ namespace tools
 	{
 	public:
 		DataListBaseControl();
-		virtual ~DataListBaseControl();
 
 		void commandCreateData(const MyGUI::UString& _commandName, bool& _result);
 		void commandCloneData(const MyGUI::UString& _commandName, bool& _result);
@@ -30,7 +29,7 @@ namespace tools
 		void setDataInfo(const std::string& _parentType, const std::string& _currentType, const std::string& _propertyName, const std::string& _propertyUnique);
 
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName) override;
 
 		bool checkCommand(bool _result);
 
