@@ -17,10 +17,9 @@ namespace tools
 	{
 	public:
 		HorizontalSelectorBlackControl();
-		virtual ~HorizontalSelectorBlackControl();
 
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName) override;
 	};
 
 }
