@@ -10,14 +10,6 @@
 namespace tools
 {
 
-	VerticalSelectorControl::VerticalSelectorControl()
-	{
-	}
-
-	VerticalSelectorControl::~VerticalSelectorControl()
-	{
-	}
-
 	void VerticalSelectorControl::OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName)
 	{
 		SelectorControl::OnInitialise(_parent, _place, "VerticalSelectorControl.layout");
