@@ -15,12 +15,8 @@ namespace tools
 	class MYGUI_EXPORT_DLL VerticalSelectorControl :
 		public SelectorControl
 	{
-	public:
-		VerticalSelectorControl();
-		virtual ~VerticalSelectorControl();
-
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName) override;
 	};
 
 }
