@@ -17,12 +17,9 @@ namespace tools
 		public ActionChangeDataProperty
 	{
 	public:
-		ChangeTextureValueAction();
-		virtual ~ChangeTextureValueAction();
-
-		virtual void doAction();
-		virtual void undoAction();
-		virtual bool doMerge(Action* _action);
+		void doAction() override;
+		void undoAction() override;
+		bool doMerge(Action* _action) override;
 
 	private:
 		std::string mOldValue;
