@@ -15,12 +15,8 @@ namespace tools
 	class GroupListControl :
 		public DataListBaseControl
 	{
-	public:
-		GroupListControl();
-		virtual ~GroupListControl();
-
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName) override;
 	};
 
 }
