@@ -18,11 +18,8 @@ namespace tools
 		public IExportSerializer
 	{
 	public:
-		ImageExportSerializer();
-		virtual ~ImageExportSerializer();
-
-		virtual void serialization(pugi::xml_document& _doc);
-		virtual bool deserialization(pugi::xml_document& _doc);
+		void serialization(pugi::xml_document& _doc) override;
+		bool deserialization(pugi::xml_document& _doc) override;
 
 	private:
 		void parseImage(pugi::xml_node _node);
