@@ -27,15 +27,15 @@
 #include "FactoryManager.h"
 #include "ComponentFactory.h"
 
-template <> tools::Application* MyGUI::Singleton<tools::Application>::msInstance = nullptr;
-template <> const char* MyGUI::Singleton<tools::Application>::mClassTypeName = "Application";
-
 namespace tools
 {
+	MYGUI_SINGLETON_DEFINITION(Application);
 
-	Application::Application()
+	Application::Application() :
+		mSingletonHolder(this)
 	{
 		ComponentFactory::Initialise();
+		mEnableVSync = true;
 	}
 
 	Application::~Application()
@@ -80,17 +80,6 @@ namespace tools
 		new HotKeyManager();
 		HotKeyManager::getInstance().initialise();
 
-		std::string language = SettingsManager::getInstance().getValue("Settings/InterfaceLanguage");
-		if (language.empty() || language == "Auto")
-		{
-			if (!mLocale.empty())
-				MyGUI::LanguageManager::getInstance().setCurrentLanguage(mLocale);
-		}
-		else
-		{
-			MyGUI::LanguageManager::getInstance().setCurrentLanguage(language);
-		}
-
 		new CommandManager();
 		CommandManager::getInstance().initialise();
 
@@ -141,7 +130,18 @@ namespace tools
 
 		MyGUI::ResourceManager::getInstance().load("Initialise.xml");
 
-		LoadGuiSettings();
+        LoadGuiSettings();
+
+        std::string language = SettingsManager::getInstance().getValue("Settings/InterfaceLanguage");
+        if (language.empty() || language == "Auto")
+        {
+            if (!mLocale.empty())
+                MyGUI::LanguageManager::getInstance().setCurrentLanguage(mLocale);
+        }
+        else
+        {
+            MyGUI::LanguageManager::getInstance().setCurrentLanguage(language);
+        }
 
 		bool maximized = SettingsManager::getInstance().getValue<bool>("Controls/Main/Maximized");
 		setWindowMaximized(maximized);
@@ -231,70 +231,6 @@ namespace tools
 		MyGUI::FactoryManager::getInstance().unregisterFactory<MyGUI::RTTLayer>(layerCategory);
 	}
 
-	void Application::setWindowMaximized(bool _value)
-	{
-	#if MYGUI_PLATFORM == MYGUI_PLATFORM_WIN32
-		if (_value)
-		{
-			size_t handle = getWindowHandle();
-			::ShowWindow((HWND)handle, SW_SHOWMAXIMIZED);
-		}
-	#endif
-	}
-
-	bool Application::getWindowMaximized()
-	{
-		bool result = false;
-	#if MYGUI_PLATFORM == MYGUI_PLATFORM_WIN32
-		size_t handle = getWindowHandle();
-		result = ::IsZoomed((HWND)handle) != 0;
-	#endif
-		return result;
-	}
-
-	void Application::setWindowCoord(const MyGUI::IntCoord& _value)
-	{
-	#if MYGUI_PLATFORM == MYGUI_PLATFORM_WIN32
-		if (_value.empty())
-			return;
-
-		MyGUI::IntCoord coord = _value;
-		if (coord.left < 0)
-			coord.left = 0;
-		if (coord.top < 0)
-			coord.top = 0;
-		if (coord.width < 640)
-			coord.width = 640;
-		if (coord.height < 480)
-			coord.height = 480;
-		if (coord.width > GetSystemMetrics(SM_CXSCREEN))
-			coord.width = GetSystemMetrics(SM_CXSCREEN);
-		if (coord.height > GetSystemMetrics(SM_CYSCREEN))
-			coord.height = GetSystemMetrics(SM_CYSCREEN);
-		if (coord.right() > GetSystemMetrics(SM_CXSCREEN))
-			coord.left = GetSystemMetrics(SM_CXSCREEN) - coord.width;
-		if (coord.bottom() > GetSystemMetrics(SM_CYSCREEN))
-			coord.top = GetSystemMetrics(SM_CYSCREEN) - coord.height;
-
-		size_t handle = getWindowHandle();
-		::MoveWindow((HWND)handle, coord.left, coord.top, coord.width, coord.height, true);
-	#endif
-	}
-
-	MyGUI::IntCoord Application::getWindowCoord()
-	{
-		MyGUI::IntCoord result;
-	#if MYGUI_PLATFORM == MYGUI_PLATFORM_WIN32
-		size_t handle = getWindowHandle();
-		::RECT rect;
-		::GetWindowRect((HWND)handle, &rect);
-		result.left = rect.left;
-		result.top = rect.top;
-		result.width = rect.right - rect.left;
-		result.height = rect.bottom - rect.top;
-	#endif
-		return result;
-	}
 
 	void Application::injectKeyPress(MyGUI::KeyCode _key, MyGUI::Char _text)
 	{
@@ -316,10 +252,12 @@ namespace tools
 		mLocale = ::setlocale( LC_ALL, "" );
 		// erase everything after '_' to get language name
 		mLocale.erase(std::find(mLocale.begin(), mLocale.end(), '_'), mLocale.end());
-		if (mLocale == "ru") mLocale = "Russian";
-		else if (mLocale == "en") mLocale = "English";
+		if (mLocale == "ru")
+			mLocale = "Russian";
+		else if (mLocale == "en")
+			mLocale = "English";
 
-	#if OGRE_PLATFORM == OGRE_PLATFORM_WIN32
+#if MYGUI_PLATFORM == MYGUI_PLATFORM_WIN32
 
 		// при дропе файл может быть запущен в любой дирректории
 		wchar_t buff[MAX_PATH];
@@ -415,9 +353,9 @@ namespace tools
 		CommandManager::getInstance().executeCommand("Command_FileDrop");
 	}
 
-	bool Application::onWinodwClose(size_t _handle)
+	bool Application::onWindowClose(size_t _handle)
 	{
-	#if OGRE_PLATFORM == OGRE_PLATFORM_WIN32
+#if MYGUI_PLATFORM == MYGUI_PLATFORM_WIN32
 		if (::IsIconic((HWND)_handle))
 			ShowWindow((HWND)_handle, SW_SHOWNORMAL);
 	#endif
