@@ -18,10 +18,9 @@ namespace tools
 	{
 	public:
 		PropertyFieldFileName(MyGUI::Widget* _parent);
-		virtual ~PropertyFieldFileName();
 
 	protected:
-		virtual bool onCheckValue();
+		bool onCheckValue() override;
 	};
 
 }
