@@ -18,10 +18,9 @@ namespace tools
 	{
 	public:
 		PropertyFieldSkin(MyGUI::Widget* _parent);
-		virtual ~PropertyFieldSkin();
 
 	protected:
-		virtual void onFillValues();
+		void onFillValues() override;
 
 	private:
 		void notifyToolTip(MyGUI::Widget* _sender, const MyGUI::ToolTipInfo& _info);
