@@ -17,17 +17,17 @@ namespace tools
 	{
 	public:
 		SettingsGeneralControl();
-		virtual ~SettingsGeneralControl();
+		~SettingsGeneralControl() override;
 
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
-		virtual void OnCommand(const std::string& _command);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName) override;
+		void OnCommand(const std::string& _command) override;
 
 	private:
 		void loadSettings();
 		void saveSettings();
 
-		void notifyNewGridStep(MyGUI::Widget* _sender, MyGUI::Widget* _new = 0);
+		void notifyNewGridStep(MyGUI::Widget* _sender, MyGUI::Widget* _new = nullptr);
 		void notifyNewGridStepAccept(MyGUI::EditBox* _sender);
 		void notifyMouseButtonClick(MyGUI::Widget* _sender);
 
