@@ -17,12 +17,9 @@ namespace tools
 		public ActionChangeDataProperty
 	{
 	public:
-		ChangeSeparatorOffsetAction();
-		virtual ~ChangeSeparatorOffsetAction();
-
-		virtual void doAction();
-		virtual void undoAction();
-		virtual bool doMerge(Action* _action);
+		void doAction() override;
+		void undoAction() override;
+		bool doMerge(Action* _action) override;
 
 	private:
 		typedef std::pair<PropertyPtr, std::string> PairProprty;
