@@ -19,12 +19,11 @@ namespace tools
 	{
 	public:
 		SkinTextureController();
-		virtual ~SkinTextureController();
 
-		virtual void setTarget(Control* _control);
+		void setTarget(Control* _control) override;
 
-		virtual void activate();
-		virtual void deactivate();
+		void activate() override;
+		void deactivate() override;
 
 	private:
 		void notifyChangeDataSelector(DataPtr _data, bool _changeOnlySelection);
