@@ -20,10 +20,9 @@ namespace tools
 	{
 	public:
 		StateListControl();
-		virtual ~StateListControl();
 
 	protected:
-		virtual void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName);
+		void OnInitialise(Control* _parent, MyGUI::Widget* _place, const std::string& _layoutName) override;
 
 	private:
 		ListBoxDataControl* mListBoxControl;
