@@ -3,8 +3,8 @@
 	@author		George Evmenov
 	@date		01/2011
 */
-#ifndef __DEMO_KEEPER_H__
-#define __DEMO_KEEPER_H__
+#ifndef DEMO_KEEPER_H_
+#define DEMO_KEEPER_H_
 
 #include "Base/BaseDemoManager.h"
 
@@ -15,13 +15,14 @@ namespace demo
 		public base::BaseDemoManager
 	{
 	public:
-		virtual void createScene();
-		virtual void destroyScene();
+		void createScene() override;
+		void destroyScene() override;
 
 		void handleClick_MemberFunction(MyGUI::Widget* _sender);
+		void handleClick_ConstMemberFunction(MyGUI::Widget* _sender) const;
 		static void handleClick_StaticMemberFunction(MyGUI::Widget* _sender);
 	};
 
 } // namespace demo
 
-#endif // __DEMO_KEEPER_H__
+#endif // DEMO_KEEPER_H_
