@@ -3,10 +3,11 @@
 	@author		Albert Semenov
 	@date		08/2008
 */
-#ifndef __I_ANIMATION_GRAPH_H__
-#define __I_ANIMATION_GRAPH_H__
+#ifndef I_ANIMATION_GRAPH_H_
+#define I_ANIMATION_GRAPH_H_
 
-#include <Ogre.h>
+#include <OgrePrerequisites.h>
+#include <OgreAny.h>
 #include <string>
 #include "IAnimationNode.h"
 
@@ -18,8 +19,7 @@ namespace animation
 	{
 	public:
 		IAnimationGraph() : IAnimationNode() { }
-		IAnimationGraph(const std::string& _name) : IAnimationNode(_name, 0) { }
-		virtual ~IAnimationGraph() { }
+		IAnimationGraph(const std::string& _name) : IAnimationNode(_name, nullptr) { }
 
 		virtual Ogre::Any getData(const std::string& _name) = 0;
 		virtual void addData(const std::string& _name, Ogre::Any _any) = 0;
@@ -31,4 +31,4 @@ namespace animation
 
 } // namespace animation
 
-#endif // __I_DATA_DICTONARY_H__
+#endif // I_DATA_DICTONARY_H_
