@@ -21,11 +21,10 @@ namespace demo
 
 	public:
 		ControllerRandomProgress() : mTime(0) { }
-		virtual ~ControllerRandomProgress() { }
 
-		virtual bool addTime(MyGUI::Widget* _widget, float _time)
+		bool addTime(MyGUI::Widget* _widget, float _time) override
 		{
-			const float slice = 0.2;
+			const float slice = 0.2f;
 			mTime += _time;
 			if (mTime > slice)
 			{
@@ -36,7 +35,7 @@ namespace demo
 			return true;
 		}
 
-		virtual void prepareItem(MyGUI::Widget* _widget)
+		void prepareItem(MyGUI::Widget* _widget) override
 		{
 			mTime = 0;
 			action(_widget);
