@@ -4,8 +4,8 @@
 	@date		06/2008
 */
 
-#ifndef __MYGUI_RTT_LAYER_H__
-#define __MYGUI_RTT_LAYER_H__
+#ifndef MYGUI_RTT_LAYER_H_
+#define MYGUI_RTT_LAYER_H_
 
 #include "MyGUI_Prerequest.h"
 #include "MyGUI_Types.h"
@@ -25,15 +25,15 @@ namespace MyGUI
 
 	public:
 		RTTLayer();
-		virtual ~RTTLayer();
+		~RTTLayer() override;
 
-		virtual void deserialization(xml::ElementPtr _node, Version _version);
+		void deserialization(xml::ElementPtr _node, Version _version) override;
 
-		virtual void renderToTarget(IRenderTarget* _target, bool _update);
+		void renderToTarget(IRenderTarget* _target, bool _update) override;
 
-		virtual ILayerItem* getLayerItemByPoint(int _left, int _top) const;
+		ILayerItem* getLayerItemByPoint(int _left, int _top) const override;
 
-		virtual IntPoint getPosition(int _left, int _top) const;
+		IntPoint getPosition(int _left, int _top) const override;
 
 		void setTextureSize(const IntSize& _size);
 
@@ -45,4 +45,4 @@ namespace MyGUI
 
 } // namespace MyGUI
 
-#endif // __MYGUI_RTT_LAYER_H__
+#endif // MYGUI_RTT_LAYER_H_
