@@ -36,7 +36,7 @@ namespace unittest
 		}
 
 		//------------------------------------------------------------------------------//
-		//  
+		// манипуляции айтемами
 
 		//! Get number of columns
 		size_t getColumnCount() const
@@ -60,7 +60,7 @@ namespace unittest
 			column.name = _name;
 			column.data = _data;
 
-			//    ,      
+			// если уже были столбики, то делаем то же колличество полей
 			if (false == mVectorColumnInfo.empty())
 			{
 				size_t count = mVectorColumnInfo.front().list->getItemCount();
@@ -97,7 +97,7 @@ namespace unittest
 
 
 		//------------------------------------------------------------------------------//
-		//  
+		// манипуляции отображением
 
 		/** Set column name
 			@param _column Index of column
@@ -117,7 +117,7 @@ namespace unittest
 		}
 
 		//------------------------------------------------------------------------------//
-		//  
+		// манипуляции данными
 
 		//! Replace an item data at a specified position
 		void setColumnDataAt(size_t _index, MyGUI::Any _data)
@@ -141,13 +141,13 @@ namespace unittest
 		}
 
 		//------------------------------------------------------------------------------//
-		// Methods for work with lines (RU:    )
+		// Methods for work with lines (RU:методы для работы со строками)
 		/** @note
 		All indexes used here is indexes of unsorted Multilist. Even if you sorted
 			it - all items indexes will be same as before sort.*/
 
 		//------------------------------------------------------------------------------//
-		//  
+		// манипуляции айтемами
 
 		/** Get number of items (lines) */
 		size_t getItemCount() const
@@ -163,7 +163,7 @@ namespace unittest
 			MYGUI_ASSERT_RANGE_INSERT(_index, mVectorColumnInfo.front().list->getItemCount(), "MultiListBox::insertItemAt");
 			if (MyGUI::ITEM_NONE == _index) _index = mVectorColumnInfo.front().list->getItemCount();
 
-			//     ,    
+			// вставляем во все поля пустые, а потом присваиваем первому
 			for (VectorColumnInfo::iterator iter = mVectorColumnInfo.begin(); iter != mVectorColumnInfo.end(); ++iter)
 			{
 				(*iter).list->insertItemAt(_index, "");
@@ -209,7 +209,7 @@ namespace unittest
 
 
 		//------------------------------------------------------------------------------//
-		//  
+		// манипуляции отображением
 
 		/** Set item string */
 		void setItemNameAt(size_t _index, const MyGUI::UString& _name)
@@ -217,14 +217,14 @@ namespace unittest
 			setSubItemNameAt(0, _index, _name);
 		}
 
-		const MyGUI::UString& getItemNameAt(size_t _index)
+		const MyGUI::UString& getItemNameAt(size_t _index) const
 		{
 			return getSubItemNameAt(0, _index);
 		}
 
 
 		//------------------------------------------------------------------------------//
-		//  
+		// манипуляции данными
 
 		//! Replace an item data at a specified position
 		void setItemDataAt(size_t _index, MyGUI::Any _data)
@@ -247,9 +247,9 @@ namespace unittest
 
 
 		//------------------------------------------------------------------------------//
-		// Methods for work with sub lines (RU:     )
+		// Methods for work with sub lines (RU:методы для работы со саб строками)
 		//------------------------------------------------------------------------------//
-		//  
+		// манипуляции данными
 
 		/** Set sub item
 			@param _column Index of column
@@ -265,7 +265,7 @@ namespace unittest
 		}
 
 		/** Get sub item name*/
-		const MyGUI::UString& getSubItemNameAt(size_t _column, size_t _index)
+		const MyGUI::UString& getSubItemNameAt(size_t _column, size_t _index) const
 		{
 			MYGUI_ASSERT_RANGE(_column, mVectorColumnInfo.size(), "MultiListBox::getSubItemNameAt");
 			MYGUI_ASSERT_RANGE(_index, mVectorColumnInfo.begin()->list->getItemCount(), "MultiListBox::getSubItemNameAt");
@@ -281,7 +281,7 @@ namespace unittest
 		}
 
 		//------------------------------------------------------------------------------//
-		//  
+		// манипуляции данными
 
 		//! Replace an item data at a specified position
 		void setSubItemDataAt(size_t _column, size_t _index, MyGUI::Any _data)
