@@ -21,10 +21,10 @@ namespace MyGUI
 
 	public:
 		RTTLayer();
-		virtual ~RTTLayer();
+		~RTTLayer() override;
 
-		virtual void deserialization(xml::ElementPtr _node, Version _version);
-		virtual void renderToTarget(IRenderTarget* _target, bool _update);
+		void deserialization(xml::ElementPtr _node, Version _version) override;
+		void renderToTarget(IRenderTarget* _target, bool _update) override;
 
 		void setTextureSize(const IntSize& _size);
 		void setTextureName(const std::string& _name);
@@ -33,7 +33,7 @@ namespace MyGUI
 		MyGUI::ITexture* mTexture;
 		IntSize mTextureSize;
 		std::string mTextureName;
-		bool mOutOfDate;
+		bool mOutOfDateRtt;
 	};
 
 } // namespace MyGUI
