@@ -3,8 +3,8 @@
 	@author		George Evmenov
 	@date		07/2010
 */
-#ifndef __DEMO_KEEPER_H__
-#define __DEMO_KEEPER_H__
+#ifndef DEMO_KEEPER_H_
+#define DEMO_KEEPER_H_
 
 #include "Base/BaseDemoManager.h"
 
@@ -17,10 +17,10 @@ namespace demo
 	public:
 		DemoKeeper();
 
-		virtual void createScene();
+		void createScene() override;
 
 	private:
-		virtual void setupResources();
+		void setupResources() override;
 
 		void makeBezier(const std::vector<MyGUI::FloatPoint>& _points, size_t _pointsNumber);
 		void updateSpline();
@@ -41,4 +41,4 @@ namespace demo
 
 } // namespace demo
 
-#endif // __DEMO_KEEPER_H__
+#endif // DEMO_KEEPER_H_
