@@ -24,12 +24,12 @@ namespace demo
 	public:
 		FadeNodeAnimator();
 
-		virtual void attach(MyGUI::ILayerNode* _node);
+		void attach(MyGUI::ILayerNode* _node) override;
 
-		virtual void create();
-		virtual void destroy();
+		void create() override;
+		void destroy() override;
 
-		virtual size_t animate(
+		size_t animate(
 			bool _update,
 			size_t _quad_count,
 			MyGUI::VectorQuadData& _data,
@@ -39,12 +39,12 @@ namespace demo
 			const MyGUI::RenderTargetInfo& _info,
 			const MyGUI::IntCoord& _coord,
 			bool& _isAnimate
-		);
+		) override;
 
 	private:
 		void addTime(float _time);
 
-		virtual void deserialization(MyGUI::xml::ElementPtr _node, MyGUI::Version _version);
+		void deserialization(MyGUI::xml::ElementPtr _node, MyGUI::Version _version) override;
 
 	private:
 		float mFadeDuration;
